@@ -63,6 +63,7 @@
  *  sasl_setpass      Change a password or add a user entry
  *  sasl_auxprop_request  Request auxiliary properties
  *  sasl_auxprop_getctx   Get auxiliary property context for connection
+ *  sasl_auxprop_store    Store a set of auxiliary properties
  *
  * Basic client model:
  *  1. client calls sasl_client_init() at startup to load plug-ins
@@ -121,42 +122,10 @@
 
 #define SASL_VERSION_MAJOR 2
 #define SASL_VERSION_MINOR 1
-#define SASL_VERSION_STEP 14
+#define SASL_VERSION_STEP 19
 
 #include "prop.h"
 
-/* The following ifdef block is the standard way of creating macros
- * which make exporting from a DLL simpler. All files within this DLL
- * are compiled with the LIBSASL_EXPORTS symbol defined on the command
- * line. this symbol should not be defined on any project that uses
- * this DLL. This way any other project whose source files include
- * this file see LIBSASL_API functions as being imported from a DLL,
- * wheras this DLL sees symbols defined with this macro as being
- * exported.  */
-/* Under Unix, life is simpler: we just need to mark library functions
- * as extern.  (Technically, we don't even have to do that.) */
-#ifdef WIN32
-# ifdef LIBSASL_EXPORTS
-#  define LIBSASL_API  __declspec(dllexport)
-# else /* LIBSASL_EXPORTS */
-#  define LIBSASL_API  __declspec(dllimport)
-# endif /* LIBSASL_EXPORTS */
-#else /* WIN32 */
-# define LIBSASL_API extern
-#endif /* WIN32 */
-
-/* Same as above, but used during a variable declaration. Only Unix definition
- * is different, as we can't assign an initial value to an extern variable */ 
-#ifdef WIN32
-# ifdef LIBSASL_EXPORTS
-#  define LIBSASL_VAR  __declspec(dllexport)
-# else /* LIBSASL_EXPORTS */
-#  define LIBSASL_VAR  __declspec(dllimport)
-# endif /* LIBSASL_EXPORTS */
-#else /* WIN32 */
-# define LIBSASL_VAR
-#endif /* WIN32 */
-
 /*************
  * Basic API *
  *************/
@@ -650,10 +619,29 @@ typedef int sasl_canon_user_t(sasl_conn_t *conn,
 
 /* get sasl library version information
  * implementation is a vendor-defined string
- * version is a vender-defined representation of the version # */
+ * version is a vender-defined representation of the version #
+ *
+ * this function is being deprecated in favor of sasl_version_info */
 LIBSASL_API void sasl_version(const char **implementation,
 			      int *version);
 
+/* Extended version of sasl_version().
+ *
+ * This function is to be used
+ *  for library version display and logging
+ *  for bug workarounds in old library versions
+ *
+ * The sasl_version_info is not to be used for API feature detection.
+ *
+ * All parameters are optional. If NULL is specified, the value is not returned.
+ */
+LIBSASL_API void sasl_version_info (const char **implementation,
+				const char **version_string,
+				int *version_major,
+				int *version_minor,
+				int *version_step,
+				int *version_patch);
+
 /* dispose of all SASL plugins.  Connection
  * states have to be disposed of before calling this.
  */
@@ -729,12 +717,6 @@ LIBSASL_API int sasl_getprop(sasl_conn_t *conn, int propnum,
 #define SASL_CALLBACK     7	/* current callback function list */
 #define SASL_IPLOCALPORT  8	/* iplocalport string passed to server_new */
 #define SASL_IPREMOTEPORT 9	/* ipremoteport string passed to server_new */
-#define SASL_SERVICE      12	/* service passed to sasl_*_new */
-#define SASL_SERVERFQDN   13	/* serverFQDN passed to sasl_*_new */
-#define SASL_AUTHSOURCE   14	/* name of auth source last used, useful
-				 * for failed authentication tracking */
-#define SASL_MECHNAME     15    /* active mechanism name, if any */
-#define SASL_AUTHUSER     16    /* authentication/admin user */
 
 /* This returns a string which is either empty or has an error message
  * from sasl_seterror (e.g., from a plug-in or callback).  It differs
@@ -743,6 +725,22 @@ LIBSASL_API int sasl_getprop(sasl_conn_t *conn, int propnum,
  */
 #define SASL_PLUGERR     10
 
+/* a handle to any delegated credentials or NULL if none is present 
+ * is returned by the mechanism. The user will probably need to know
+ * which mechanism was used to actually known how to make use of them
+ * currently only implemented for the gssapi mechanism */
+#define SASL_DELEGATEDCREDS 11  
+
+#define SASL_SERVICE      12	/* service passed to sasl_*_new */
+#define SASL_SERVERFQDN   13	/* serverFQDN passed to sasl_*_new */
+#define SASL_AUTHSOURCE   14	/* name of auth source last used, useful
+				 * for failed authentication tracking */
+#define SASL_MECHNAME     15    /* active mechanism name, if any */
+#define SASL_AUTHUSER     16    /* authentication/admin user */
+#define SASL_APPNAME	  17	/* application name (used for logging/
+				   configuration), same as appname parameter
+				   to sasl_server_init */
+   
 /* set property in SASL connection state
  * returns:
  *  SASL_OK       -- value set
@@ -1088,6 +1086,9 @@ LIBSASL_API int sasl_setpass(sasl_conn_t *conn,
 			     unsigned flags);
 #define SASL_SET_CREATE  0x01   /* create a new entry for user */
 #define SASL_SET_DISABLE 0x02	/* disable user account */
+#define SASL_SET_NOPLAIN 0x04	/* do not store secret in plain text */
+#define SASL_SET_CURMECH_ONLY 0x08	/* set the mechanism specific password only.
+					   fail if no current mechanism */
 
 /*********************************************************
  * Auxiliary Property Support -- added by cjn 1999-09-29 *
@@ -1096,7 +1097,8 @@ LIBSASL_API int sasl_setpass(sasl_conn_t *conn,
 #define SASL_AUX_END      NULL	/* last auxiliary property */
 
 /* traditional Posix items (should be implemented on Posix systems) */
-#define SASL_AUX_PASSWORD "*userPassword" /* User Password (of authid) */
+#define SASL_AUX_PASSWORD_PROP "userPassword" /* User Password */
+#define SASL_AUX_PASSWORD "*" SASL_AUX_PASSWORD_PROP /* User Password (of authid) */
 #define SASL_AUX_UIDNUM   "uidNumber"	/* UID number for the user */
 #define SASL_AUX_GIDNUM   "gidNumber"	/* GID for the user */
 #define SASL_AUX_FULLNAME "gecos"	/* full name of the user, unix-style */
@@ -1139,6 +1141,25 @@ LIBSASL_API int sasl_auxprop_request(sasl_conn_t *conn,
  */
 LIBSASL_API struct propctx *sasl_auxprop_getctx(sasl_conn_t *conn);
 
+/* Store the set of auxiliary properties for the given user.
+ * Use functions in prop.h to set the content.
+ *
+ *  conn         connection context
+ *  ctx          property context from prop_new()/prop_request()/prop_set()
+ *  user         NUL terminated user
+ *
+ * Call with NULL 'ctx' to see if the backend allows storing properties.
+ *
+ * errors
+ *  SASL_OK       -- success
+ *  SASL_NOMECH   -- can not store some/all properties
+ *  SASL_BADPARAM -- bad conn/ctx/user parameter
+ *  SASL_NOMEM    -- out of memory
+ *  SASL_FAIL     -- failed to store
+ */
+LIBSASL_API int sasl_auxprop_store(sasl_conn_t *conn,
+				   struct propctx *ctx, const char *user);
+
 /**********************
  * security layer API *
  **********************/
