@@ -1,7 +1,7 @@
 /* dlopen.c--Unix dlopen() dynamic loader interface
  * Rob Siemborski
  * Rob Earhart
- * $Id: dlopen.c,v 1.44 2003/02/13 19:55:54 rjs3 Exp $
+ * $Id: dlopen.c,v 1.48 2004/03/10 15:38:13 rjs3 Exp $
  */
 /* 
  * Copyright (c) 1998-2003 Carnegie Mellon University.  All rights reserved.
@@ -92,6 +92,7 @@
 #endif
 
 #ifdef __hpux
+#ifndef HAVE_DLFCN_H
 #include <dl.h>
 
 typedef shl_t dll_handle;
@@ -142,6 +143,7 @@ char *dlerror()
     return "Generic shared library error";
 }
 
+#endif /* HAVE_DLFCN_H */
 #define SO_SUFFIX	".sl"
 #else /* __hpux */
 #define SO_SUFFIX	".so"
@@ -165,7 +167,7 @@ int _sasl_locate_entry(void *library, const char *entryname,
 #ifdef DO_DLOPEN
 /* note that we still check for known problem systems in
  * case we are cross-compiling */
-#if defined(DLSYM_NEEDS_UNDERSCORE) || defined(__OpenBSD__) || defined(__APPLE__)
+#if defined(DLSYM_NEEDS_UNDERSCORE) || (defined(__OpenBSD__) && !defined(__ELF__))
     char adj_entryname[1024];
 #else
 #define adj_entryname entryname
@@ -189,7 +191,7 @@ int _sasl_locate_entry(void *library, const char *entryname,
 	return SASL_BADPARAM;
     }
 
-#if defined(DLSYM_NEEDS_UNDERSCORE) || defined(__OpenBSD__) || defined(__APPLE__)
+#if defined(DLSYM_NEEDS_UNDERSCORE) || (defined(__OpenBSD__) && !defined(__ELF__))
     snprintf(adj_entryname, sizeof adj_entryname, "_%s", entryname);
 #endif
 
