@@ -1,7 +1,7 @@
 /* CRAM-MD5 SASL plugin
  * Rob Siemborski
  * Tim Martin 
- * $Id: cram.c,v 1.81 2003/11/03 18:25:24 ken3 Exp $
+ * $Id: cram.c,v 1.83 2003/12/15 20:04:22 rjs3 Exp $
  */
 /* 
  * Copyright (c) 1998-2003 Carnegie Mellon University.  All rights reserved.
@@ -65,7 +65,7 @@
 
 /*****************************  Common Section  *****************************/
 
-static const char plugin_id[] = "$Id: cram.c,v 1.81 2003/11/03 18:25:24 ken3 Exp $";
+static const char plugin_id[] = "$Id: cram.c,v 1.83 2003/12/15 20:04:22 rjs3 Exp $";
 
 /* convert a string of 8bit chars to it's representation in hex
  * using lowercase letters
@@ -220,7 +220,8 @@ crammd5_server_mech_step2(server_context_t *text,
 {
     char *userid = NULL;
     sasl_secret_t *sec = NULL;
-    int pos, len;
+    int pos;
+    unsigned len;
     int result = SASL_FAIL;
     const char *password_request[] = { SASL_AUX_PASSWORD,
 				       "*cmusaslsecretCRAM-MD5",
@@ -303,6 +304,9 @@ crammd5_server_mech_step2(server_context_t *text,
 	return SASL_FAIL;
     }
     
+    /* erase the plaintext password */
+    sparams->utils->prop_erase(sparams->propctx, password_request[0]);
+
     /* ok this is annoying:
        so we have this half-way hmac transform instead of the plaintext
        that means we half to:
@@ -321,8 +325,11 @@ crammd5_server_mech_step2(server_context_t *text,
     
     /* if same then verified 
      *  - we know digest_str is null terminated but clientin might not be
+     *  - verify the length of clientin anyway!
      */
-    if (strncmp(digest_str, clientin+pos+1, strlen(digest_str)) != 0) {
+    len = strlen(digest_str);
+    if (clientinlen-pos-1 < len ||
+	strncmp(digest_str, clientin+pos+1, len) != 0) {
 	sparams->utils->seterror(sparams->utils->conn, 0,
 				 "incorrect digest response");
 	result = SASL_BADAUTH;
