@@ -1,7 +1,7 @@
 /* Kerberos4 SASL plugin
  * Rob Siemborski
  * Tim Martin 
- * $Id: kerberos4.c,v 1.100 2009/03/10 16:27:52 mel Exp $
+ * $Id: kerberos4.c,v 1.97 2004/02/06 17:23:51 rjs3 Exp $
  */
 /* 
  * Copyright (c) 1998-2003 Carnegie Mellon University.  All rights reserved.
@@ -115,7 +115,7 @@ extern int gethostname(char *, int);
 
 /*****************************  Common Section  *****************************/
 
-static const char plugin_id[] = "$Id: kerberos4.c,v 1.100 2009/03/10 16:27:52 mel Exp $";
+static const char plugin_id[] = "$Id: kerberos4.c,v 1.97 2004/02/06 17:23:51 rjs3 Exp $";
 
 #ifndef KEYFILE
 #define KEYFILE "/etc/srvtab";
@@ -237,10 +237,6 @@ static int kerberosv4_encode(void *context,
     KRB_LOCK_MUTEX(text->utils);
     
     if (text->sec_type == KRB_SEC_ENCRYPTION) {
-	/* Type incompatibility on 4th arg probably means you're
-	   building against krb4 in MIT krb5, but got the OpenSSL
-	   headers in your way. You need to not use openssl/des.h with
-	   MIT kerberos. */
 	len=krb_mk_priv(inblob->data, (text->encode_buf+4),
 			inblob->curlen,  text->init_keysched, 
 			&text->session, &text->ip_local,
@@ -518,7 +514,6 @@ static int kerberosv4_server_mech_step(void *conn_context,
 	KTEXT_ST ticket;
 	unsigned lup;
 	struct sockaddr_in addr;
-	char *dot;
 	
 	/* received authenticator */
 	
@@ -544,14 +539,6 @@ static int kerberosv4_server_mech_step(void *conn_context,
 	KRB_UNLOCK_MUTEX(sparams->utils);
 	
 	text->instance[sizeof(text->instance)-1] = 0;
-
-	/* At some sites, krb_get_phost() sensibly but
-	 * atypically returns FQDNs, versus the first component,
-	 * which is what we need for RFC2222 section 7.1
-	 */
-	dot = strchr(text->instance, '.');
-	if (dot) *dot = '\0';
-
 	memset(&addr, 0, sizeof(struct sockaddr_in));
 	
 #ifndef KRB4_IGNORE_IP_ADDRESS
@@ -745,7 +732,7 @@ static int kerberosv4_server_mech_step(void *conn_context,
 	if (sparams->canon_user) {
 	    char *user=NULL, *authid=NULL;
 	    size_t ulen = 0, alen = strlen(text->pname);
-	    int ret, cflag = SASL_CU_AUTHID | SASL_CU_EXTERNALLY_VERIFIED;
+	    int ret, cflag = SASL_CU_AUTHID;
 	    
 	    if (text->pinst[0]) {
 		alen += strlen(text->pinst) + 1 /* for the . */;
@@ -970,7 +957,6 @@ static int kerberosv4_client_mech_step(void *conn_context,
 	 * We want to reply with an authenticator. */
 	int result;
 	KTEXT_ST ticket;
-	char *dot;
 	
 	memset(&ticket, 0L, sizeof(ticket));
 	ticket.length = MAX_KTXT_LEN;   
@@ -1008,13 +994,6 @@ static int kerberosv4_client_mech_step(void *conn_context,
 	
 	/* text->instance is NULL terminated unless it was too long */
 	text->instance[sizeof(text->instance)-1] = '\0';
-
-	/* At some sites, krb_get_phost() sensibly but
-	 * atypically returns FQDNs, versus the first component,
-	 * which is what we need for RFC2222 section 7.1
-	 */
-	dot = strchr(text->instance, '.');
-	if (dot) *dot = '\0';
 	
 #ifndef macintosh
 	if ((result = krb_mk_req(&ticket, (char *) cparams->service, 
