@@ -1,3 +1,5 @@
+#define PWBUFSZ 256 /***SWB***/
+
 /* MODULE: auth_shadow */
 
 /* COPYRIGHT
@@ -28,7 +30,7 @@
  * END COPYRIGHT */
 
 #ifdef __GNUC__
-#ident "$Id: auth_shadow.c,v 1.5 2003/02/03 17:09:11 rjs3 Exp $"
+#ident "$Id: auth_shadow.c,v 1.7 2004/04/27 15:56:23 rjs3 Exp $"
 #endif
 
 /* PUBLIC DEPENDENCIES */
@@ -93,15 +95,22 @@ auth_shadow (
 
 # ifdef HAVE_GETSPNAM
 
-/**************
- * getspnam() *
- *************/
+ /***************
+ * getspnam_r() *
+ ***************/
 
     /* VARIABLES */
-    struct passwd	*pw;		/* return from getpwent() */
-    struct spwd   	*sp;		/* return from getspnam() */
     long today;				/* the current time */
     char *cpw;				/* pointer to crypt() result */
+    struct passwd	*pw;		/* return from getpwnam_r() */
+    struct spwd   	*sp;		/* return from getspnam_r() */
+#  ifdef _REENTRANT
+    struct passwd pwbuf;
+    char pwdata[PWBUFSZ];		/* pwbuf indirect data goes in here */
+
+    struct spwd spbuf;
+    char spdata[PWBUFSZ];		/* spbuf indirect data goes in here */
+#  endif /* _REENTRANT */
     /* END VARIABLES */
 
 #  define RETURN(x) return strdup(x)
@@ -121,10 +130,14 @@ auth_shadow (
 #  define SHADOW_PW_LOCKED "*LK*"	/* account locked (not used by us) */
 #  define SHADOW_PW_EPERM  "*NP*"	/* insufficient database perms */
 
+#  ifdef _REENTRANT
+    pw = getpwnam_r(login, &pwbuf, pwdata, sizeof(pwdata));
+#  else
     pw = getpwnam(login);
+#  endif /* _REENTRANT */
     endpwent();
     if (pw == NULL) {
-	if (debug) {
+	if (flags & VERBOSE) {
 	    syslog(LOG_DEBUG, "DEBUG: auth_shadow: getpwnam(%s) returned NULL", login);
 	}
 	RETURN("NO");
@@ -132,18 +145,22 @@ auth_shadow (
 
     today = (long)time(NULL)/(24L*60*60);
 
+#  ifdef _REENTRANT
+    sp = getspnam_r(login, &spbuf, spdata, sizeof(spdata));
+#  else
     sp = getspnam(login);
+#  endif /* _REENTRANT */
     endspent();
 
     if (sp == NULL) {
-	if (debug) {
+	if (flags & VERBOSE) {
 	    syslog(LOG_DEBUG, "DEBUG: auth_shadow: getspnam(%s) returned NULL", login);
 	}
 	RETURN("NO");
     }
 
     if (!strcmp(sp->sp_pwdp, SHADOW_PW_EPERM)) {
-	if (debug) {
+	if (flags & VERBOSE) {
 	    syslog(LOG_DEBUG, "DEBUG: auth_shadow: sp->sp_pwdp == SHADOW_PW_EPERM");
 	}
 	RETURN("NO Insufficient permission to access NIS authentication database (saslauthd)");
@@ -157,7 +174,7 @@ auth_shadow (
      */
     cpw = strdup((const char *)crypt(password, sp->sp_pwdp));
     if (strcmp(sp->sp_pwdp, cpw)) {
-	if (debug) {
+	if (flags & VERBOSE) {
 	    syslog(LOG_DEBUG, "DEBUG: auth_shadow: pw mismatch: '%s' != '%s'",
 		   sp->sp_pwdp, cpw);
 	}
@@ -174,7 +191,7 @@ auth_shadow (
      */
 
     if ((sp->sp_expire != -1) && (today > sp->sp_expire)) {
-	if (debug) {
+	if (flags & VERBOSE) {
 	    syslog(LOG_DEBUG, "DEBUG: auth_shadow: account expired: %dl > %dl",
 		   today, sp->sp_expire);
 	}
@@ -186,7 +203,7 @@ auth_shadow (
     if (sp->sp_lstchg != -1) {
 
 	if ((sp->sp_max != -1) && ((sp->sp_lstchg + sp->sp_max) < today)) {
-	    if (debug) {
+	    if (flags & VERBOSE) {
 		syslog(LOG_DEBUG,
 		       "DEBUG: auth_shadow: password expired: %ld + %ld < %ld",
 		       sp->sp_lstchg, sp->sp_max, today);
@@ -194,7 +211,7 @@ auth_shadow (
 	    RETURN("NO Password expired");
 	}
     }
-    if (debug) {
+    if (flags & VERBOSE) {
 	syslog(LOG_DEBUG, "DEBUG: auth_shadow: OK: %s", login);
     }
     RETURN("OK");
@@ -219,7 +236,7 @@ auth_shadow (
     upw = getuserpw(login);
   
     if (upw == 0) {
-	if (debug) {
+	if (flags & VERBOSE) {
 	    syslog(LOG_DEBUG, "auth_shadow: getuserpw(%s) == 0",
 		   login);
 	}
@@ -227,7 +244,7 @@ auth_shadow (
     }
   
     if (strcmp(upw->upw_passwd, crypt(password, upw->upw_passwd)) != 0) {
-	if (debug) {
+	if (flags & VERBOSE) {
 	    syslog(LOG_DEBUG, "auth_shadow: pw mismatch: %s != %s",
 		   password, upw->upw_passwd);
 	}
